pub struct ResourcePool<T> {
    pub holder: Arc<Mutex<ResourceHolder<T>>>,
}
Versatile resource pool

Fields

holder: Arc<Mutex<ResourceHolder<T>>>

Implementations

source

impl<T> ResourcePool<T>

source

pub fn new() -> Self

Create new resource pool

source

pub fn with_capacity(size: usize) -> Self

Create new resource pool with pre-allocated capacity

The size parameter is used to pre-allocate memory for the resource holder only

source

pub fn append(&self, res: T)

Append resource to the pool

Panics

This function might panic when called if the resource lock is already held by the current thread

source

pub async fn get(&self) -> ResourcePoolGuard<T>

Get resource from the pool or wait until one is available