pub struct ResourcePoolGuard<T> { /* fields omitted */ }
Returns a reference to the original resource
Do not return resource back to the pool when dropped
Replace resource with a new one
The resulting type after dereferencing.
Mutably dereferences the value.
Executes the destructor for this type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.